import { Link } from "react-router-dom";
import { openCity } from "./HorizontalTimeline";

interface UrlButtonProps{
    href: string,
    children: string,
  };


export function Villagebutton({ title, source, page }: { title: string; source: string; page:string}) {
  return (
    <Link className="btn village-style-button" role="button" to={page}>
      <img src={source} className="d-block mx-auto mb-2" alt=""></img>
      <h3>{title}</h3>
    </Link>
  )
}

export function Villbuttonrow(){
  return(
      <div className="row align-items-center bottom-buttons">
        <Villagebutton page="/human-practices" source="https://static.igem.wiki/teams/5247/design/icons/humanpractices.png" title="Human Practice"></Villagebutton>
        <Villagebutton page="/team" source="https://static.igem.wiki/teams/5247/design/icons/team.png" title="Team"></Villagebutton>
        <Villagebutton page="/experiments" source="https://static.igem.wiki/teams/5247/design/icons/lab.png" title="Experiments"></Villagebutton>
        <Villagebutton page="/description" source="https://static.igem.wiki/teams/5247/design/icons/dna.png" title="Description"></Villagebutton>
        <Villagebutton page="/engineering" source="https://static.igem.wiki/teams/5247/design/icons/genetic-engineering.png" title="Engineering"></Villagebutton>
        <Villagebutton page="/safety" source="https://static.igem.wiki/teams/5247/design/icons/safety.png" title="Safety"></Villagebutton>
        <Villagebutton page="/results" source="https://static.igem.wiki/teams/5247/design/icons/results.png" title="Results"></Villagebutton>
      </div>  
  )
}


export const UrlButton = ({ href, children }:UrlButtonProps) => {
    return (
      <a href={href} className="url-button">
        {children}
      </a>
    );
  }




export const DownloadLink = ({ url, fileName }: {url: string, fileName: string}) => {
const handleDownload = () => {
    fetch(url)
    .then((response) => response.blob())
    .then((blob) => {
        const url = window.URL.createObjectURL(new Blob([blob]));
        const link = document.createElement("a");
        link.href = url;
        link.download = fileName || "downloaded-file";
        document.body.appendChild(link);

        link.click();

        document.body.removeChild(link);
        window.URL.revokeObjectURL(url);
    })
    .catch((error) => {
        console.error("Error fetching the file:", error);
    });
};
  
return (

    <a type="button" onClick={handleDownload} className="download-butt">
        Download
    </a>

);
};


export function TabButtonRow({data, classy, opentype, closing}: {data: Array<TabDatensatz>, classy?: string, opentype: string, closing: string}){
  let rows = []
  for ( let i = 0;  i < data.length; i++ ){
    if(classy){
      rows.push(<TabButton classy={classy} type={data[i].cssname} name={data[i].buttonname} opentype={opentype} closing={closing}/>)
    }
    else{
      rows.push(<TabButton type={data[i].cssname} name={data[i].buttonname} opentype={opentype} closing={closing}/>)
    }
  }
  return <div className="align-items-center bottom-buttons">
    {rows}
  </div>; 
}



interface TabButtonProps{
  classy?: string, 
  closing: string, 
  opentype: string
  /* children?: React.ReactNode,  */
  /* onClick: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void,  */
  name: string,
  type: string
}
// neuer 
export function TabButton({classy, name, closing, opentype, type}:TabButtonProps){
  if (!classy){
    classy = ""
  }
  let classname = "tabbutton " + type + " " + classy; 
  return(
    <>
    <button className={classname} onClick={openTab({cityName: type, cla: opentype, weg: closing })}> {name}</button>
    </>
  )
}

export function HPMoreButton({name}: {name: string}){
  return(
    <button className="tablinks hp-more-button" onClick={openCity({cityName: name})}> More</button>
  )
}

export function openTab({cityName, cla, weg}:{cityName: string, cla: string, weg?: string}) {
  const opencity =  (event : React.MouseEvent<HTMLButtonElement, MouseEvent>) =>{
    var i, tabcontent, tablinks, wegcontent;
  tabcontent = document.getElementsByClassName(cla);
  for (i = 0; i < tabcontent.length; i++) {
    (tabcontent[i] as HTMLElement).style.display = "none";
  }
  tablinks = document.getElementsByClassName("tabbutton");
  for (i = 0; i < tablinks.length; i++) {
    tablinks[i].className = tablinks[i].className.replace(" active", "");
  }
  if (weg){
    wegcontent  = document.getElementsByClassName(weg);
    for (i = 0; i < wegcontent.length; i++) {
      (wegcontent[i] as HTMLElement).style.display = "none";
    }
  }
  document.getElementById(cityName)!.style.display = "block";
  event.currentTarget.className += " active";
  }
  return opencity; 
}